tlslite.errors

Package tlslite :: Module errors |
[show private | hide private]
[frames | no frames]

## Module tlslite.errors

Exception classes.

Exceptions
`TLSError` | Base class for all TLS Lite exceptions.
`TLSAbruptCloseError` | The socket was closed without a proper TLS shutdown.
`TLSAlert` | A TLS alert has been signalled.
`TLSLocalAlert` | A TLS alert has been signalled by the local implementation.
`TLSRemoteAlert` | A TLS alert has been signalled by the remote implementation.
`TLSAuthenticationError` | The handshake succeeded, but the other party's authentication was inadequate.
`TLSNoAuthenticationError` | The Checker was expecting the other party to authenticate with a certificate chain, but this did not occur.
`TLSAuthenticationTypeError` | The Checker was expecting the other party to authenticate with a different type of certificate chain.
`TLSFingerprintError` | The Checker was expecting the other party to authenticate with a certificate chain that matches a different fingerprint.
`TLSAuthorizationError` | The Checker was expecting the other party to authenticate with a certificate chain that has a different authorization.
`TLSValidationError` | The Checker has determined that the other party's certificate chain is invalid.
`TLSFaultError` | The other party responded incorrectly to an induced fault.

Generated by Epydoc 2.0 on Mon Feb 21 21:56:56 2005 | http://epydoc.sf.net